# pysmz3 for Python 3.6/3.7!
Pyz3r is an unofficial python abstraction library for interacting with the [samus.link](https://samus.link) API.

This allows developers to create applications that not only generate games on [samus.link](https://samus.link),
but also create the ROM as well using the patch data provided by the website.

It is a very stripped down version of pyz3r.  All game patching code was removed, and most other code was removed too.

## Installation
This module is available on PyPI.  It can be installed via pip:

`pip install pysmz3`

## Compatiblity
This library has been tested on both Linux (Centos 7) and Windows on Python 3.6 and 3.7.  